@@ -1,6 +1,6 @@
 package WWW::Google::DistanceMatrix;
 
-$WWW::Google::DistanceMatrix::VERSION = '0.06';
+$WWW::Google::DistanceMatrix::VERSION = '0.07';
 
 use 5.006;
 use JSON;
@@ -23,7 +23,7 @@ WWW::Google::DistanceMatrix - Interface to Google Distance Matrix API.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
@@ -274,6 +274,10 @@ sub _result {
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
+=head1 REPOSITORY
+
+L<https://github.com/Manwar/WWW-Google-DistanceMatrix>
+
 =head1 BUGS
 
 Please  report any bugs or feature requests to C<bug-www-google-distancematrix at
