@@ -1,6 +1,6 @@
 package WWW::Google::DistanceMatrix::Params;
 
-$WWW::Google::DistanceMatrix::Params::VERSION = '0.06';
+$WWW::Google::DistanceMatrix::Params::VERSION = '0.07';
 
 use 5.006;
 use strict; use warnings;
@@ -18,7 +18,7 @@ WWW::Google::DistanceMatrix::Params - Placeholder for parameters for WWW::Google
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
@@ -128,6 +128,10 @@ sub validate {
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
+=head1 REPOSITORY
+
+L<https://github.com/Manwar/WWW-Google-DistanceMatrix>
+
 =head1 BUGS
 
 Please  report any bugs or feature requests to C<bug-www-google-distancematrix at
